@@ -37,8 +37,7 @@ from const import FIRST, LAST, ALL
 
 import parser
 import soundcard
-import string, types
-from musicalpitch import MusicalPitch
+from musicalpitch import MusicalPitch, InvalidNotenameException
 from interval import Interval
 from mpdutils import notename_to_int, int_to_notename, int_to_user_notename
 
@@ -78,8 +77,8 @@ def play_music(music, tempo, patch, velocity):
 ##################
 
 def transpose_notename(n, t):
-    assert type(n) in types.StringTypes
-    assert type(t) == types.IntType
+    assert isinstance(n, basestring)
+    assert isinstance(t, int)
     # 1 2 sekund
     # 3 4 ters
     # 5 6 kvart
@@ -97,7 +96,7 @@ def select_clef(s):
     """
     lowest = HIGHEST_NOTENAME
     highest = LOWEST_NOTENAME
-    for n in string.split(s):
+    for n in s.split():
         if compare_notenames(n, lowest) < 0:
             lowest = n
         if compare_notenames(n, highest) > 1:
