@@ -71,6 +71,10 @@ b,,
 h
 >>> print _("Close")
 Lukk
+>>> n = MusicalPitch()
+>>> n.set_from_notename("d'")
+>>> print n.get_octave_notename()
+d'
 """
 if __name__ == "__main__":
     import sys
@@ -169,9 +173,40 @@ class MusicalPitch:
             self.m_accidental_i = self.m_accidental_i + 1
         elif self.semitone_pitch()-old_p > tra:
             self.m_accidental_i = self.m_accidental_i - 1
+        self.sanitate_accidental()
         return self
-    def set_from_steps(self, steps):
-        print "x:", 6-(steps % 7) 
+    def sanitate_accidental(self):
+        """
+        Make use self.m_accidental_i is some of the values -2, -1, 0, 1, 2
+        It can be out of this range if the musicalpitch has been transposed.
+        This function will change notenames like gisisis, where m_accidental_i
+        is 3 to ais where m_accidental_i is 1
+        """
+        if not -3 < self.m_accidental_i < 3:
+            p = self.semitone_pitch()
+            self.set_from_int(p)
+    def enharmonic_flip(self):#FIXME find proper name.
+        """
+        Change the notename, so that gis becomes aes.
+        What about d, should it be cisis or eeses??
+
+        his,  c deses
+        cisis d deses
+        disis e fes
+        eis   f geses
+        fisis g aeses
+        gisis a beses
+        aisis b ces'
+
+        cis des
+        dis es
+        fis ges
+        gis aes
+        ais bes
+        """
+        if self.m_accidental_i == 1 and self.m_notename_i < 6:
+            self.m_accidental_i = -1
+            self.m_notename_i += 1
     def steps(self):
         return self.m_notename_i + self.m_octave_i * 7
     def semitone_pitch(self):
@@ -184,6 +219,8 @@ class MusicalPitch:
         self.m_accidental_i = midiint-(self.m_octave_i+4)*12 \
                               -[0, 2, 4, 5, 7, 9, 11][self.m_notename_i]
     def set_from_notename(self, notename):
+        if not notename:
+            raise InvalidNotenameException(notename)
         tmp = notename
         self.m_accidental_i = self.m_octave_i = 0
         while notename[-1] in ["'", ","]:
