@@ -230,7 +230,6 @@ def get_bool(key):
     elif get_string(key) == 'false':
         return 0
     else:
-        print "warning: cfg.get_bool: value of '%s' is not true or false" % key
         return 0
 
 #####################################
@@ -391,9 +390,12 @@ class ConfigUtils(object):
     def get_bool(self, name):
         return self._get(get_bool, name)
     def get_list(self, name):
-        if '=' in name:
-            return eval(self._get(get_string, name))
-        return eval(self._get(get_string, name, "=[]"))
+        try:
+            if '=' in name:
+                return eval(self._get(get_string, name))
+            return eval(self._get(get_string, name, "=[]"))
+        except SyntaxError:
+            return []
 
 
 if __name__ == '__main__':
