@@ -36,13 +36,11 @@ def find_wav_player_programs():
     return ret
 
 def find_midi_player_programs():
-    ret = []
     for p, cmd in (('/usr/bin/timidity', '/usr/bin/timidity -idqq %s'),
                    ('/usr/bin/drvmidi', '/usr/bin/drvmidi'),
                    ('/usr/bin/playmidi', '/usr/bin/playmidi')):
         if os.path.exists(p):
-            ret.append(p)
-    return ret
+            yield cmd
 
 class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def on_destroy(self, widget, e):
@@ -86,6 +84,13 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_instrsel = nInstrumentSelector('config',
                         'preferred_instrument', sizegroup)
         category_vbox.pack_start(self.g_instrsel, False)
+
+        box, category_vbox = gu.hig_category_vbox(_("Chord instruments"))
+        page_vbox.pack_start(box, False)
+        self.g_instrument_configurator  \
+              = widgets.InstrumentConfigurator("config", 3,
+                    _("Use different instruments for chords and harmonic intervals."))
+        category_vbox.pack_start(self.g_instrument_configurator, False)
         ########
         # user #
         ########
@@ -131,35 +136,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Gui")))
 
-        box, category_vbox = gu.hig_category_vbox(_("Main toolbar"))
-        page_vbox.pack_start(box, False)
-
-        self.g_toolbar_checkbutton = gu.nCheckButton('gui', 'toolbar_visible', _("Show"))
-        self.g_toolbar_checkbutton.connect('clicked',
-            lambda w: self.g_toolbar_radio_box.set_sensitive(w.get_active()))
-        category_vbox.pack_start(self.g_toolbar_checkbutton)
-
-        self.g_toolbar_radio_box = hbox = gtk.HBox()
-        category_vbox.pack_start(hbox)
-        self.g_toolbar_radio_box.set_sensitive(self.get_bool('gui/toolbar_visible'))
-
-        self.g_toolbar_icons = gu.RadioButton(None, _("Icons"))
-        self.g_toolbar_icons.connect('toggled', lambda w: self.m_app.set_string('gui/toolbar_style', 'icons'))
-        hbox.pack_start(self.g_toolbar_icons, False)
-        self.g_toolbar_text = gu.RadioButton(self.g_toolbar_icons, _("Text"))
-        self.g_toolbar_text.connect('toggled', lambda w: self.m_app.set_string('gui/toolbar_style', 'text'))
-        hbox.pack_start(self.g_toolbar_text, False)
-        self.g_toolbar_both = gu.RadioButton(self.g_toolbar_icons, _("Both"))
-        self.g_toolbar_both.connect('toggled', lambda w: self.m_app.set_string('gui/toolbar_style', 'both'))
-        hbox.pack_start(self.g_toolbar_both, False)
-        self.__dict__['g_toolbar_'+self.get_string('gui/toolbar_style=icons')].set_active(True)
-
-        self.g_navbar_checkbutton = gu.nCheckButton('gui', 'navbar_visible', _("Show navigation buttons"))
-        self.g_navbar_checkbutton.set_sensitive(self.get_bool('gui/toolbar_visible'))
-        category_vbox.pack_start(self.g_navbar_checkbutton)
-
-        self.g_toolbar_checkbutton.connect('clicked', lambda w: self.g_navbar_checkbutton.set_sensitive(w.get_active()))
-
         box, category_vbox = gu.hig_category_vbox(_("External programs"))
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
@@ -176,6 +152,11 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_mainwin_user_resizeable = gu.nCheckButton('gui',
           'mainwin_user_resizeable', _("_User resizeable main window"))
         category_vbox.pack_start(self.g_mainwin_user_resizeable, False)
+
+        self.g_expert_mode = gu.nCheckButton('gui', 
+                'expert_mode', _("E_xpert mode"))
+        self.g_expert_mode.connect('toggled', self.m_app.reset_exercise)
+        category_vbox.pack_start(self.g_expert_mode, False)
         ############
         # Practise #
         ############
