@@ -44,18 +44,9 @@ class Teacher(abstract.LessonbasedTeacher):
     QSTATUS_NO mean that the question is corrupt and unusable. Other
                questions in the same file might be useable.
     """
-    def __init__(self, exname, app, lesson_collection, lesson_file, config):
-        abstract.LessonbasedTeacher.__init__(self, exname, app,
-                lesson_collection, lesson_file, config)
+    def __init__(self, exname, app):
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.DictationLessonfile
-        try:
-            self.parse_lessonfile()
-        except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_exception_message(e, __file__)
-        else:
-            #to please abstract.LessonParser
-            self.q_status = const.QSTATUS_NEW
-            self.m_P.select_first()
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -247,7 +238,6 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.clear()
             self.action_area.set_sensitive(False)
         self._update()
-        self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def create_pixmap_button(self):
         im = gtk.Image()
         im.set_from_stock("solfege-rhythm-c4", gtk.ICON_SIZE_LARGE_TOOLBAR)
