@@ -107,7 +107,7 @@ class nCheckButton(gtk.CheckButton, cfg.ConfigUtils):
         self.set_bool(self.m_name, self.get_bool(self.m_name+"="+s))
         if self.get_bool(self.m_name):
             self.set_active(1)
-        self._clicked_id = self.connect('clicked', self.on_clicked)
+        self._clicked_id = self.connect('toggled', self.on_clicked)
         self._watch_id = self.add_watch(self.m_name, self._watch_cb)
     def _watch_cb(self, name):
         self.set_active(self.get_bool(name))
