@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'identify-bpm',
     'stock-icon': 'solfege-identify-bpm',
-    'menupath': '/Menubar/FileMenu/RhythmMenu',
+    'menupath': '/Menubar/FileMenu/MiscMenu',
     'name': _("_Bpm"),
 }
 import exercise_setup
@@ -41,7 +41,7 @@ class Teacher(abstract.Teacher):
                        72, 76, 80, 84, 88, 92, 96, 100, 104,    # 9 - 17
                        108, 112, 116, 120, 126, 132, 138, 144,  # 18 - 25
                        152, 160, 168, 176, 184, 192, 200, 208]  # 26 - 33
-        self.m_statistics = statistics.Statistics(self)
+        #self.m_statistics = statistics.Statistics(self)
         self.m_timeout_tag = None
         self.m_question = None
         self.m_practise_these = {}
