@@ -15,32 +15,24 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__exercise_data__ = {
-    'exercise_name': 'id-tone',
-    'stock-icon': 'solfege-id-tone',
-    'menupath': '/Menubar/FileMenu/MiscMenu',
-    'name': _('Id_entify tone'),
-}
-import exercise_setup
-exercise_setup.register_exercise(__exercise_data__)
-
 import inputwidgets, abstract, const, random, soundcard, gu, mpd, gnome
 import gobject
 import runtime
 import gtk
 import gu
 import statistics, statisticsviewer
+import lessonfile
 
-class Teacher(abstract.Teacher):
-    exercise_data = __exercise_data__
+class Teacher(abstract.LessonbasedTeacher):
     #FIXME the following lines
     OK, ERR_PICKY, ERR_TONES = range(3)
     ERR_PICKY = 1
     ERR_CONFIG = 2
     OCTAVES = [-2, -1, 0, 1, 2, 3]
-    def __init__(self, exname, app, config):
-        abstract.Teacher.__init__(self, exname, app, config)
-        self.m_statistics = statistics.Statistics(self)
+    def __init__(self, exname, app):
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        self.m_statistics = statistics.LessonStatistics(self)
         self.m_ask_tones =   {}
         self.m_question = None
     def new_question(self):
@@ -80,14 +72,16 @@ class Teacher(abstract.Teacher):
         return self.OK
     def guess_answer(self, notename):
         if notename == self.m_question:
-            if self.q_status == const.QSTATUS_NEW:
+            if self.q_status == const.QSTATUS_NEW \
+                    and not self.get_bool('gui/expert_mode'):
                 self.m_statistics.add_correct(notename)
             self.maybe_auto_new_question()
             self.q_status = const.QSTATUS_SOLVED
             return 1
         else:
             if self.q_status == const.QSTATUS_NEW:
-                self.m_statistics.add_wrong(self.m_question, notename)
+                if not self.get_bool('gui/expert_mode'):
+                    self.m_statistics.add_wrong(self.m_question, notename)
                 self.q_status = const.QSTATUS_WRONG
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
@@ -96,7 +90,8 @@ class Teacher(abstract.Teacher):
              mpd.notename_to_int(self.m_question)+self.m_octave*12,
              self.get_int('config/preferred_instrument_velocity'))
     def give_up(self):
-        self.m_statistics.reset_session()
+        if not self.get_bool('gui/expert_mode'):
+            self.m_statistics.reset_session()
         self.q_status = const.QSTATUS_GIVE_UP
     def spank_me_play_question(self):
         track = soundcard.Track()
@@ -148,10 +143,13 @@ right now. But I can answer questions if needed.""")))
         # config_box #
         ##############
         self.config_box.set_spacing(gnome.ui.PAD_SMALL)
+        # bad variable name, but this is the config options that should
+        # not change without chaning lesson_id
+        self.g_config_elems = gu.bVBox(self.config_box)
         table = gtk.Table()
         table.set_border_width(gnome.ui.PAD_SMALL)
         frame = gtk.Frame(_("Weight"))
-        self.config_box.pack_start(frame, False)
+        self.g_config_elems.pack_start(frame, False)
         frame.add(table)
         for x, n in [(1, 'cis'), (3, 'dis'), (7, 'fis'),
                      (9, 'gis'), (11, 'ais')]:
@@ -172,7 +170,7 @@ right now. But I can answer questions if needed.""")))
                    gtk.Adjustment(1, 0, 1000, 1, 10), digits=0)
             table.attach(b, x, x+2, 3, 4, xoptions=gtk.FILL)
 
-        hbox = gu.bHBox(self.config_box, False)
+        hbox = gu.bHBox(self.g_config_elems, False)
         hbox.pack_start(gtk.Label(_("Octave:")), False, padding=4)
         for oct in self.m_t.OCTAVES:
             b = gu.nCheckButton(self.m_exname, "octave"+str(oct), str(oct),
@@ -264,7 +262,17 @@ _("""You have to select some tones practise. Do this on the config page by setti
     def on_start_practise(self):
         if not runtime.has_gnome_canvas():
             return # this exercise don't work without GnomeCanvas
-        self.m_t.m_statistics.reset_session()
+        for n in ('c', 'cis', 'd', 'dis', 'e', 'f', 'fis', 'g', 'gis', 'a',
+                  'ais', 'b'):
+            if self.m_t.m_P.header.__getattr__('%s_weight' % n):
+                self.set_float('%s_weight' % n, float(self.m_t.m_P.header.__getattr__('%s_weight' % n)))
+            else:
+                self.set_float('%s_weight' % n, 1.0)
+        if self.get_bool('gui/expert_mode'):
+            self.g_config_elems.show()
+        else:
+            self.g_config_elems.hide()
+            self.m_t.m_statistics.reset_session()
         self.set_percentage_label()
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New tone' to begin.")))
