@@ -25,6 +25,11 @@ except:
     i18n.setup_srcdir()
 
 import xrandom
+import uuid
+import stat
+import time
+import locale
+import gethomedir
 
 class LessonfileException(Exception):
     def get_title(self):
@@ -86,15 +91,19 @@ _keys_to_interval = {
             }
 
 predef = {'dictation': 'dictation',
-          'progression': 'progression',
-          # define the harmony keyword for backward compatibility
-          'harmony': 'harmonic-progression-dictation',
-          'harmonic-progression-dictation': 'harmonic-progression-dictation',
-          'sing-chord': 'sing-chord',
+          'harmonicprogressiondictation': 'harmonicprogressiondictation',
+          'singchord': 'singchord',
           'singanswer': 'singanswer',
-          'chord-voicing': 'chord-voicing',
+          'chordvoicing': 'chordvoicing',
           'chord': 'chord',
-          'id-by-name': 'id-by-name',
+          'compareintervals': 'compareintervals',
+          'idbyname': 'idbyname',
+          'singinterval': 'singinterval',
+          'melodicinterval': 'melodicinterval',
+          'harmonicinterval': 'harmonicinterval',
+          'idtone': 'idtone',
+          #
+          'progression': 'progression',
           'normal': 'normal',
           'voice': 'voice',
           'rvoice': 'rvoice',
@@ -134,29 +143,35 @@ class _Header:
                            ('description', ''),
                            #('content', ''), This MUST be set in the lessonfile
                            ('musicformat', 'normal'),
-                           ('random_transpose', False),
+                           ('random_transpose', True),
                            ('labelformat', 'normal'),
                            ('fillnum', 1),
                            ('filldir', 'horiz'),
-                           ('questions_selectable', False),
                            ('have_repeat_slowly_button', False),
                            ('have_repeat_arpeggio_button', False),
                            ('at_question_start', []),
                            ('have_music_displayer', False),
                            ('enable_right_click', True),
+                           ('disable_unused_intervals', True),
                            ):
             if key not in self.m_headerdict:
                 self.m_headerdict[key] = value
     def __getattr__(self, name):
         if name in self.m_headerdict:
             return dataparser.get_translated_string(self.m_headerdict, name)
-        raise NameError(name)
+        print "warning: lessonfile.Header.%s not set. Returning empty string" % name
+        return ""
+        #raise NameError(name)
 
 class Music:
     def __init__(self, musicdata, musictype='normal'):
         self.m_musicdata = musicdata
         self.m_musictype = musictype
 
+def parse_test_def(s):
+    m = re.match("(\d+)\s*x", s)
+    count = int(m.groups()[0])
+    return (count, 'x')
 
 class LessonfileCommon(object):
     def __init__(self, teacher):
@@ -183,6 +198,18 @@ class LessonfileCommon(object):
                 question['music'] = Music(question['music'], self.header.musicformat)
             question['m_lessonfile'] = self
         self.m_random = xrandom.Random(range(len(self.m_questions)))
+    def generate_test_questions(self):
+        count, t = parse_test_def(self.header.test)
+        q = range(len(self.m_questions)) * count
+        random.shuffle(q)
+        return q
+    def get_test_requirement(self):
+        """
+        Return the amount of exercises that has to be correct to
+        pass the test. (values 0.0 to 1.0)
+        """
+        m = re.match("([\d\.]+)%", self.header.test_requirement)
+        return float(m.groups()[0])/100.0
     def select_random_question(self):
         """
         Select a new question by random. It will use the music in the
@@ -224,23 +251,7 @@ class LessonfileCommon(object):
                 else:
                     self._idx = random.choice(available_question_idx)
             if self.header.random_transpose:
-                if self.header.random_transpose == True:
-                    self.handle_random_transpose_is_yes()
-                # Backward compatability to handle old style
-                # random_transpose = -4, 5 FIXMECOMPAT
-                elif len(self.header.random_transpose) == 2:
-                    self.header.random_transpose \
-                        = ['semitones'] + self.header.random_transpose
-                if 'key' in self.m_questions[self._idx]:
-                    key = self.m_questions[self._idx]['key']
-                else:
-                    key = "c \major"
-                if self.header.random_transpose[0] == 'semitones':
-                    self.m_transpose = self.semitone_find_random_transpose()
-                    if random.randint(0, 1):
-                        self.m_transpose.enharmonic_flip()
-                else:
-                    self.m_transpose = self.find_random_transpose(key)
+                self.set_random_transpose()
             if count == 10:
                 break
             if self.m_prev_question == self.get_music() \
@@ -249,6 +260,24 @@ class LessonfileCommon(object):
             break
         self.m_random.add(self._idx)
         self.m_prev_question = self.get_music()
+    def set_random_transpose(self):
+        if self.header.random_transpose == True:
+            self.handle_random_transpose_is_yes()
+        # Backward compatability to handle old style
+        # random_transpose = -4, 5 FIXMECOMPAT
+        elif len(self.header.random_transpose) == 2:
+            self.header.random_transpose \
+                = ['semitones'] + self.header.random_transpose
+        if 'key' in self.m_questions[self._idx]:
+            key = self.m_questions[self._idx]['key']
+        else:
+            key = "c \major"
+        if self.header.random_transpose[0] == 'semitones':
+            self.m_transpose = self.semitone_find_random_transpose()
+            if random.randint(0, 1):
+                self.m_transpose.enharmonic_flip()
+        else:
+            self.m_transpose = self.find_random_transpose(key)
     def semitone_find_random_transpose(self):
         """
         Called to find random transposition in "semitone" mode.
@@ -473,6 +502,20 @@ class LessonfileCommon(object):
         Return True if a question is selected.
         """
         return self._idx is not None
+    def enter_test_mode(self):
+        self.m_test_questions = self.generate_test_questions()
+        self.m_test_idx = -1
+    def next_test_question(self):
+        assert self.m_test_idx < len(self.m_test_questions)
+        self.m_test_idx += 1
+        self._idx = self.m_test_questions[self.m_test_idx]
+        if self.header.random_transpose:
+            self.set_random_transpose()
+    def is_test_complete(self):
+        """
+        Return True if the test is compleded.
+        """
+        return self.m_test_idx == len(self.m_test_questions) -1
     def play_question(self, question=None, varname='music'):
         """Play the question. Play the current question if question is none.
         varname is the name of the variable that contains the music.
@@ -621,13 +664,13 @@ class LessonfileCommon(object):
         Use app default values if the variable is missing.
         Convert instrument names to integer values.
         """
-        if self.m_t.get_bool('override_default_instrument'):
-            instrument = [self.m_t.get_int('highest_instrument'),
-                         self.m_t.get_int('highest_instrument_velocity'),
-                         self.m_t.get_int('middle_instrument'),
-                         self.m_t.get_int('middle_instrument_velocity'),
-                         self.m_t.get_int('lowest_instrument'),
-                         self.m_t.get_int('lowest_instrument_velocity')]
+        if self.m_t.get_bool('config/override_default_instrument'):
+            instrument = [self.m_t.get_int('config/highest_instrument'),
+                         self.m_t.get_int('config/highest_instrument_velocity'),
+                         self.m_t.get_int('config/middle_instrument'),
+                         self.m_t.get_int('config/middle_instrument_velocity'),
+                         self.m_t.get_int('config/lowest_instrument'),
+                         self.m_t.get_int('config/lowest_instrument_velocity')]
         elif 'instrument' in question:
             instrument = question['instrument']
         elif 'instrument' in self.m_globals:
@@ -723,7 +766,7 @@ class IdByNameLessonfile(LessonfileCommon):
             self.header.have_music_displayer = True
         # Also, if some questions has cuemusic, then we need the displayer
         if [q for q in self.m_questions if 'cuemusic' in q]:
-            self.m_header.have_music_displayer = True
+            self.header.have_music_displayer = True
         # Delete questions that does not have a name
         q = self.m_questions
         self.m_questions = []
@@ -797,6 +840,7 @@ class LessonFileManager:
         self.parse()
     def parse(self):
         self.m_db = {}
+        self.m_uiddb = {}
         self.m_invalid_files = []
         vim_tmpfile_re = re.compile("\..*\.swp")
         for collection in cfg.get_list("config/lessoncollections"):
@@ -810,6 +854,13 @@ class LessonFileManager:
                 if filename in ('CVS', 'Makefile', 'Makefile.in') \
                   or not os.path.isfile(self.get_complete_filename(collection, filename)):
                     continue
+                try:
+                    f = LessonIdParser(self.get_complete_filename(collection, filename))
+                    if not f.has_lesson_id():
+                        f.add_lesson_id()
+                except IOError, e:
+                    print >> sys.stderr, "add_lesson_id: Failed because file is write protected: '%s'" % self.get_complete_filename(collection, filename)
+                    continue
                 try:
                     p = dataparser.Dataparser(predef, lessonfile_functions)
                     p.parse_file(self.get_complete_filename(collection, filename))
@@ -818,19 +869,47 @@ class LessonFileManager:
                     print >> sys.stderr, "LessonFileManager.parse: Discarding lessonfile '%s/%s' because the file contain errors:" % (collection, filename)
                     print >> sys.stderr, str(e)
                     continue
-                c = p.header['content']
-                if isinstance(c, basestring):
-                    c = [c]
-                for u in c:
+                if 'title' in p.header:
+                    title = p.header['title']
+                else:
+                    title = ""
+                if 'url' in p.header:
+                    url = p.header['url']
+                    #p.header['content'] = utils.Url(p.header['url']).exercisemodule
+                else:
+                    url = None
+                if 'content' not in p.header:
+                    if 'module' not in p.header:
+                        print " Hopper over", filename
+                        continue
+                    p.header['content'] = p.header['module']
+                if isinstance(p.header['content'], basestring):
+                    p.header['content'] = [p.header['content']]
+                if not 'title' in p.header:
+                    p.header['title'] = '@@@NOT TITLE'
+                for u in p.header['content']:
                     if u not in self.m_db[collection]:
                         self.m_db[collection][u] = []
-                    if 'title' in p.header:
-                        title = p.header['title']
-                    else:
-                        title = ""
                     self.m_db[collection][u].append({'filename': filename,
-                                                     'title': title}
+                                                     'title': title,
+                                                     'lesson_id': p.header['lesson_id']}
                                                 )
+                n = {
+                   'filename': self.get_complete_filename(collection, filename),
+                   'lessoncollection': collection,#FIXME rename lessoncollection
+                   'lessonfile': filename,
+                   'url': url,
+                   'lesson_id': p.header['lesson_id'],
+                   'mtime': os.stat(self.get_complete_filename(collection, filename))[stat.ST_MTIME],
+                   'header': p.header,
+                }
+                if not p.header['lesson_id'] in self.m_uiddb:
+                    self.m_uiddb[p.header['lesson_id']] = n
+                else:
+                    if type(self.m_uiddb[p.header['lesson_id']]) != list:
+                        self.m_uiddb[p.header['lesson_id']] = \
+                            [self.m_uiddb[p.header['lesson_id']]]
+                    self.m_uiddb[p.header['lesson_id']].append(n)
         for collection in self.m_db.itervalues():
             for content in collection:
                 collection[content].sort()
@@ -847,10 +926,58 @@ class LessonFileManager:
                 for d in self.m_db[collection][use]:
                     fn = d['filename']
                     self.m_htmldoc = self.m_htmldoc + \
-                      "<br><a href=\"solfege:practise/%(use)s/%(collection)s/%(fn)s\">%(fn)s</a>: %(title)s\n" % {'use':use, 'collection': collection,
+                      "<br><a href=\"solfege:practise/%(collection)s/%(fn)s\">%(fn)s</a>: %(title)s\n" % {'use':use, 'collection': collection,
                         'fn': fn, 'title': d['title']}
                 self.m_htmldoc += "</p>"
         self.m_htmldoc = self.m_htmldoc + "</body></html>"
+    def get(self, lesson_id, fieldname):
+        if fieldname in ('title', 'test', 'content', 'module'):
+            if fieldname in self.m_uiddb[lesson_id]['header']:
+                return self.m_uiddb[lesson_id]['header'][fieldname]
+            elif fieldname == 'module':
+                print "warning: update %s to use the new 'module' variable" % self.get(lesson_id, 'filename')
+                s = self.m_uiddb[lesson_id]['header']['content'][0]
+                s = s.replace("-", "")
+                return s
+        if fieldname in self.m_uiddb[lesson_id]:
+            return self.m_uiddb[lesson_id][fieldname]
+    def is_test_passed(self, lesson_id):
+        return os.path.exists(os.path.join(gethomedir.get_home_dir(),
+            '.solfege', 'testresults', lesson_id, 'passed'))
+    def ignore_files_with_lesson_id(self, lesson_id):
+        """
+        Delete lesson files from .m_db if they have the lesson_id lesson_id.
+        """
+        for collection in self.m_db:
+            for use in self.m_db[collection]:
+                for d in self.m_db[collection][use]:
+                    if d['lesson_id'] == lesson_id:
+                        d['ignore'] = True
+                self.m_db[collection][use] = [d for d in self.m_db[collection][use] if 'ignore' not in d]
+    def iterate_duplicated_lesson_id(self):
+        """
+        Return the a lesson_id if there exist lesson_ids that
+        are duplicated. If not, return None.
+        """
+        for v in self.m_uiddb.values():
+            if isinstance(v, list):
+                yield v[0]['lesson_id']
+    def iterate_lesson_ids(self):
+        for k in self.m_uiddb:
+            yield k
+    def get_lesson_file_info(self, lesson_id):
+        """
+        FIXME: the function name is not very good.
+        Return data used to fix things when we have a lesson_id crash.
+        """
+        return [{'filename': d['filename'], 'timestr': time.strftime(locale.nl_langinfo(locale.D_T_FMT), time.localtime(d['mtime'])), 'mtime': d['mtime']} for d in self.m_uiddb[lesson_id]]
+    def get_href_from_uuid(self, lesson_id):
+        if 'url' in self.m_uiddb[lesson_id]['header']:
+            return self.m_uiddb[lesson_id]['header']['url']
+        return "solfege:practise/%s/%s/%s" % (
+            self.m_uiddb[lesson_id]['header']['content'][0],
+            self.m_uiddb[lesson_id]['collection'],
+            self.m_uiddb[lesson_id]['lessonfile'])
     def get_collections(self):
         """
         Return a list of available collections. 
@@ -878,6 +1005,72 @@ class LessonFileManager:
         else:
             return []
 
+class LessonIdParser(object):
+    """
+    This is a light weight parser for lesson files that is only used when
+    checking/adding/updating lesson_ids.
+    """
+    def __init__(self, filename):
+        self.m_filename = filename
+        f = file(filename, 'r')
+        self.m_file_content = f.read()
+        f.close()
+    def has_header_block(self):
+        """
+        Return True if the file has a header block.
+        """
+        return re.search("[^#]\s*header", self.m_file_content) is not None
+    def has_lesson_id(self):
+        """
+        Return True if the lesson file has a lesson_id.
+        """
+        return re.search("lesson_id", self.m_file_content) is not None
+    def new_lesson_id(self):
+        """
+        Generate and add a new lesson_id for the file filename.
+        """
+        if self.has_lesson_id():
+            ofile = file(self.m_filename, 'w')
+            m = re.search("lesson_id\s*=\s*\".+?\"", self.m_file_content)
+            ofile.write(self.m_file_content[:m.start()])
+            ofile.write("lesson_id = \"%s\"" % uuid.generate())
+            ofile.write(self.m_file_content[m.end():])
+            ofile.close()
+        else:
+            print "warning: new_lesson_id when we have no id. Ok anyway."
+            self.add_lesson_id()
+    def add_header_block(self):
+        """
+        Add a header block with a lesson id.
+        """
+        assert not self.has_header_block()
+        v = self.m_file_content.split("\n")
+        for i in range(len(v)):
+            if not v[i].startswith('#'):
+                break
+        v.insert(i+1, "header { \n    lesson_id=\"%s\"\n}" % uuid.generate())
+        self.m_file_content = "\n".join(v)
+        ofile = file(self.m_filename, 'w')
+        ofile.write(self.m_file_content)
+        ofile.close()
+    def add_lesson_id(self):
+        """
+        Add a lesson id to m_file_content and write it to disk.
+        """
+        assert not self.has_lesson_id()
+        if not self.has_header_block():
+            self.add_header_block()
+        else:
+            ofile = file(self.m_filename, 'w')
+            m = re.search("^[^\#]\s*header\s*{", self.m_file_content,
+                            re.MULTILINE)
+            if m:
+                ofile.write(self.m_file_content[:m.start()])
+                ofile.write("\nheader {")
+                ofile.write("\n    lesson_id = \"%s\"" % uuid.generate())
+                ofile.write(self.m_file_content[m.end():])
+            ofile.close()
+
 if __name__ == '__main__':
     import time
     t1 = time.clock()
