@@ -18,13 +18,14 @@
 __exercise_data__ = {
     'exercise_name': 'rhythm',
     'stock-icon': 'solfege-rhythm',
-    'menupath': '/Menubar/FileMenu/RhythmMenu',
+    'menupath': '/Menubar/FileMenu/MiscMenu',
     'name': _("_Rhythm"),
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
 import gtk, gnome.ui, gobject
+import widgets
 import abstract, const, gu, mpd, soundcard
 import random, os
 import cfg
@@ -73,6 +74,8 @@ class Teacher(abstract.Teacher):
                 v.append(x)
         if not v:
             return Teacher.ERR_NO_ELEMS
+        if not norest_v:
+            return Teacher.ERR_NO_ELEMS
         self.m_question = [random.choice(norest_v)]
         for x in range(1, self.get_int("num_beats")):
             self.m_question.append(random.choice(v))
@@ -209,6 +212,9 @@ class RhythmViewer(gtk.Frame):
         "return the number of rhythm elements currently viewed"
         return len(self.m_data)
     def sad_face(self):
+        l = widgets.HarmonicProgressionLabel(_("Wrong"))
+        l.show()
+        self.g_box.pack_start(l, False)
         self.g_face = gtk.EventBox()
         self.g_face.connect('button_press_event', self.on_sadface_event)
         self.g_face.show()
@@ -218,6 +224,9 @@ class RhythmViewer(gtk.Frame):
         self.g_face.add(im)
         self.g_box.pack_start(self.g_face, False)
     def happy_face(self):
+        l = widgets.HarmonicProgressionLabel(_("Correct"))
+        l.show()
+        self.g_box.pack_start(l, False)
         self.g_face = gtk.EventBox()
         self.g_face.connect('button_press_event', self.on_happyface_event)
         self.g_face.show()
