@@ -15,16 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__exercise_data__ = {
-    'exercise_name': 'singanswer',
-    'stock-icon': 'solfege-sing-answer',
-    'menupath': '/Menubar/FileMenu/ChordsMenu',
-    'name': _("_Sing answer"),
-    'notoolbar': True,
-}
-import exercise_setup
-exercise_setup.register_exercise(__exercise_data__)
-
+import gobject
 import gtk
 import gu
 import abstract
@@ -36,17 +27,11 @@ import const
 import soundcard
 
 class Teacher(abstract.LessonbasedTeacher):
-    exercise_data = __exercise_data__
     OK = 1
     ERR_NO_QUESTION = 2
-    def __init__(self, exname, app, lesson_collection, lesson_file, config):
-        abstract.LessonbasedTeacher.__init__(self, exname, app, 
-                   lesson_collection, lesson_file, config)
+    def __init__(self, exname, app):
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingAnswerLessonfile
-        try: # the lesson file might contain errors.
-            self.parse_lessonfile()
-        except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_exception_message(e, __file__)
     def new_question(self):
         # TODO This function is very similar to the one in src/idbyname.py
         self.q_status = const.QSTATUS_NO
@@ -63,8 +48,8 @@ class Gui(abstract.LessonbasedGui):
         abstract.Gui.__init__(self, teacher, window)
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.practise_box.pack_start(self.g_music_displayer)
-        self.g_question = gtk.Label()
-        self.practise_box.pack_start(self.g_question)
+        self.g_flashbar = gu.FlashBar()
+        self.practise_box.pack_start(self.g_flashbar)
         self.g_music_displayer.clear()
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
@@ -74,7 +59,6 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.add_select_lessonfile_gui()
         self.add_random_transpose_gui()
         self.show_all()
         self.update_gui_after_lessonfile_change()
@@ -90,11 +74,12 @@ class Gui(abstract.LessonbasedGui):
         try:
             g = self.m_t.new_question()
             self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
-            self.g_question.set_text(self.m_t.m_P.get_question()['question_text'])
+            self.g_flashbar.push(self.m_t.m_P.get_question()['question_text'])
             self.m_t.m_P.play_question()
             self.g_repeat.set_sensitive(True)
             self.g_repeat_arpeggio.set_sensitive(True)
             self.g_play_answer.set_sensitive(True)
+            self.g_play_answer.grab_focus()
         except lessonfile.LessonfileException, e:
             exception_cleanup()
             self.g_win.display_exception_message(e, __file__)
@@ -118,6 +103,7 @@ class Gui(abstract.LessonbasedGui):
             soundcard.synth.stop()
             self.g_win.display_question_music_error_message(
                 self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+        self.g_new.grab_focus()
     def update_gui_after_lessonfile_change(self):
         if self.m_t.m_P:
             self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
@@ -136,5 +122,12 @@ class Gui(abstract.LessonbasedGui):
             self.g_repeat.set_sensitive(False)
             self.g_repeat_arpeggio.set_sensitive(False)
             self.g_play_answer.set_sensitive(False)
+        self.g_flashbar.clear()
         self.g_new.set_sensitive(bool(self.m_t.m_P))
-        self.g_win.set_title("Solfege - " + self.get_pretty_name())
+    def on_start_practise(self):
+        self.g_new.grab_focus()
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
+            self.g_flashbar.flash(_("Click 'New' to begin.")))
+        self.g_flashbar.require_size(
+            [q['question_text'] for q in self.m_t.m_P.m_questions]
+            + [_("Click 'New' to begin.")])
