@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,15 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__exercise_data__ = {
-    'exercise_name': 'sing-chord',
-    'menu_path': '%s/%s' % (_("_Chords"), _("Sin_g chord")),
-    'icon': 'graphics/singchord24.png',
-    'toolbar': 10,
-}
-import exercise_setup
-exercise_setup.register_exercise(__exercise_data__)
-
 import gtk, gnome
 import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract
 import lessonfile
@@ -32,15 +23,9 @@ import utils
 import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
-    exercise_data = __exercise_data__
-    def __init__(self, exname, app, lesson_collection, lesson_file, config):
-        abstract.LessonbasedTeacher.__init__(self, exname, app,
-            lesson_collection, lesson_file, config)
+    def __init__(self, exname, app):
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingChordLessonfile
-        try: # the lessonfile might contain errors.
-            self.parse_lessonfile()
-        except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_error_message(str(e))
     def new_question(self):
         self.q_status = const.QSTATUS_NEW
         self.m_P.select_random_question()
@@ -71,7 +56,6 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.add_select_lessonfile_gui()
         self.add_random_transpose_gui()
         self.update_gui_after_lessonfile_change()
     def new_question(self, widget=None):
@@ -115,5 +99,4 @@ class Gui(abstract.LessonbasedGui):
         else:
             self.g_new.set_sensitive(False)
         self.g_play_answer.set_sensitive(False)
-        self.g_win.set_title("Solfege - " + self.get_pretty_name())
 
