@@ -45,7 +45,7 @@ class MatrixTable(gtk.VBox):
                 l.set_alignment(0.0, 0.5)
             t.attach(l, 0, 1, y*2, y*2+1, xpadding=gnome.ui.PAD)
             for x in range(len(keys)):
-                if dict.has_key(keys[x]) and dict[keys[x]].has_key(keys[y]):
+                if keys[x] in dict and keys[y] in dict[keys[x]]:
                     s = str(dict[keys[x]][keys[y]])
                 else:
                     s = "0"
@@ -109,8 +109,11 @@ class PercentagesTable(gtk.Frame):
                        ('last7', statistics.m_last7_stat),
                        ('total', statistics.m_total_stat)):
 
-                self.boxdict[sk+'percent'].pack_start(
-                    gtk.Label("%.0f" % statistics.get_percentage_correct(st, k)))
+                if statistics.get_percentage_correct(st, k) == 0.0:
+                    self.boxdict[sk+'percent'].pack_start(gtk.Label("-"))
+                else:
+                    self.boxdict[sk+'percent'].pack_start(
+                        gtk.Label("%.0f" % statistics.get_percentage_correct(st, k)))
                 self.boxdict[sk+'count'].pack_start(
                     gtk.Label(str(statistics.get_num_guess(st, k))))
         self.show_all()
